from .dict_util import get_by_dotted as dict_get_dotted
from .date import EDate, EDateTime, to_edatetime, to_edate, generate_months
from .data import EData
from .color import generate_random_color, hex_to_rgb, rgb_to_hex, darken_color
from .compute_total_and_difference import compute_total_and_difference, compute_difference_percent
